Package 'shinyDSP'

Title: A Shiny App For Visualizing Nanostring GeoMx DSP Data
Description: This package is a Shiny app for interactively analyzing and visualizing Nanostring GeoMX Whole Transcriptome Atlas data. Users have the option of exploring a sample data to explore this app's functionality. Regions of interest (ROIs) can be filtered based on any user-provided metadata. Upon taking two or more groups of interest, all pairwise and ANOVA-like testing are automatically performed. Available ouputs include PCA, Volcano plots, tables and heatmaps. Aesthetics of each output are highly customizable.
Authors: Seung J. Kim [aut, cre] (ORCID: <https://orcid.org/0000-0001-5263-0758>), Marco Mura [aut, fnd]
Maintainer: Seung J. Kim <[email protected]>
License: MIT + file LICENSE
Version: 1.5.0
Built: 2026-05-15 10:12:45 UTC
Source: https://github.com/bioc/shinyDSP

Help Index


Creates the shiny app, ready to be loaded

Description

Creates the shiny app, ready to be loaded

Usage

shinyDSP()

Value

A shiny::shinyApp() object

Author(s)

Seung J. Kim

Examples

library(shinyDSP)
app <- shinyDSP()
if (interactive()) {
    shiny::runApp(app)
}